@@ -7,6 +7,7 @@ from typing import Dict
 
 from gdeltdoc.helpers import load_json
 
+from gdeltdoc._version import version
 
 class GdeltDoc:
     """
@@ -147,11 +148,21 @@ class GdeltDoc:
         ]:
             raise ValueError(f"Mode {mode} not in supported API modes")
 
+        headers = {
+            "User-Agent": f"GDELT DOC Python API client {version} - https://github.com/alex9smith/gdelt-doc-api"
+        }
+
         response = requests.get(
-            f"https://api.gdeltproject.org/api/v2/doc/doc?query={query_string}&mode={mode}&format=json"
+            f"https://api.gdeltproject.org/api/v2/doc/doc?query={query_string}&mode={mode}&format=json",
+            headers=headers
         )
 
         if response.status_code not in [200, 202]:
             raise ValueError("The gdelt api returned a non-successful statuscode. This is the response message: {}".
                              format(response.text))
+
+        # Response is text/html if it's an error and application/json if it's ok
+        if "text/html" in response.headers["content-type"]:
+            raise ValueError(f"The query was not valid. The API error message was: {response.text.strip()}")
+
         return load_json(response.content, self.max_depth_json_parsing)
